@@ -175,6 +175,8 @@ my %_ac_macro_for_var =
    CXXFLAGS => 'AC_PROG_CXX',
    F77 => 'AC_PROG_F77',
    F77FLAGS => 'AC_PROG_F77',
+   FC => 'AC_PROG_FC',
+   FCFLAGS => 'AC_PROG_FC',
    RANLIB => 'AC_PROG_RANLIB',
    YACC => 'AC_PROG_YACC',
    );
@@ -789,7 +791,7 @@ sub define ($$$$$$$$)
   my ($var, $owner, $type, $cond, $value, $comment, $where, $pretty) = @_;
 
   prog_error "$cond is not a reference"
-    unless ref $where;
+    unless ref $cond;
 
   prog_error "$where is not a reference"
     unless ref $where;
@@ -1190,7 +1192,7 @@ sub output_variables ()
   return $res;
 }
 
-=item C<$var-E<gt>traverse_recursively (&fun_item, &fun_collect, [cond_filter =E<gt> $cond_filter], [inner_expand =E<gt> 1])>
+=item C<$var-E<gt>traverse_recursively (&fun_item, &fun_collect, [cond_filter =E<gt> $cond_filter], [inner_expand =E<gt> 1], [skip_ac_subst =E<gt> 1])>
 
 Split the value of the Automake::Variable C<$var> on space, and
 traverse its components recursively.
@@ -1219,9 +1221,12 @@ If C<inner_expand> is set, variable references occuring in filename
 (as in C<$(BASE).ext>) are expansed before the filename is passed to
 C<&fun_item>.
 
+If C<skip_ac_subst> is set, Autoconf @substitutions@ will be skipped,
+i.e., C<&fun_item> will never be called for them.
+
 C<&fun_item> may return a list of items, they will be passed to
-C<&fun_store> later on.  Define C<&fun_item> as C<undef> when it serve
-no purpose, this will speed things up.
+C<&fun_store> later on.  Define C<&fun_item> or @<&fun_store> as
+C<undef> when they serve no purpose.
 
 Once all items of a variable have been processed, the result (of the
 calls to C<&fun_items>, or of recursive traversals of subvariables)
@@ -1255,16 +1260,18 @@ sub traverse_recursively ($&&;%)
   my ($var, $fun_item, $fun_collect, %options) = @_;
   my $cond_filter = $options{'cond_filter'};
   my $inner_expand = $options{'inner_expand'};
+  my $skip_ac_subst = $options{'skip_ac_subst'};
   return $var->_do_recursive_traversal ($var,
 					$fun_item, $fun_collect,
-					$cond_filter, TRUE, $inner_expand)
+					$cond_filter, TRUE, $inner_expand,
+					$skip_ac_subst)
 }
 
 # The guts of Automake::Variable::traverse_recursively.
-sub _do_recursive_traversal ($$&&$$$)
+sub _do_recursive_traversal ($$&&$$$$)
 {
   my ($var, $parent, $fun_item, $fun_collect, $cond_filter, $parent_cond,
-      $inner_expand) = @_;
+      $inner_expand, $skip_ac_subst) = @_;
 
   $var->set_seen;
 
@@ -1331,7 +1338,8 @@ sub _do_recursive_traversal ($$&&$$$)
 							  $fun_collect,
 							  $cond_filter,
 							  $full_cond,
-							  $inner_expand);
+							  $inner_expand,
+							  $skip_ac_subst);
 	      push (@result, @res);
 
 	      pop @_substfroms;
@@ -1376,6 +1384,10 @@ sub _do_recursive_traversal ($$&&$$$)
 	      # We do not know any variable with this name.  Fall through
 	      # to filename processing.
 	    }
+	  elsif ($skip_ac_subst && $val =~ /^\@.+\@$/)
+	    {
+	      next;
+	    }
 
 	  if ($fun_item) # $var is a filename we must process
 	    {
@@ -1401,6 +1413,8 @@ sub _do_recursive_traversal ($$&&$$$)
   # is free to use the same variable several times in the same definition.
   $var->{'scanned'} = -1;
 
+  return ()
+    unless $fun_collect;
   # Make sure you update the doc of Automake::Variable::traverse_recursively
   # if you change the prototype of &fun_collect.
   return &$fun_collect ($var, $parent_cond, @allresults);
